#ifndef __CHM_IGC_MESSAGE_RECEIVED_RESPONSE_H__
#define __CHM_IGC_MESSAGE_RECEIVED_RESPONSE_H__
//---------------------------------------------------------------------------
// Copyright (C) 1997-2009 iNTERFACEWARE Inc.  All Rights Reserved
//
// Module: CHMIGCmessageReceivedResponse
//
// Author: Steven Dodd
// Date:   Jan 20, 2009
// Revision: $Revision: 1.4 $
//
// Last Edit Date: $Date: 2009-02-19 03:35:01 $
// Source: $Source: /home/cvs/cvsroot/CHM/Attic/CHMIGCmessageReceivedResponse.h,v $
//---------------------------------------------------------------------------

#include <CHM/CHMminimumInclude.h>

class CHMIGCdll;
class CHMstring;

/** Captures plugin response to an CHMIGCdestination::onMessageReceived() event. */
class CHMIGCmessageReceivedResponse 
{
public:
   // his is used internally, not for external use.
   CHMIGCmessageReceivedResponse(CHMIGCdll& Dll, void* ResponseHandle);

   // non-virtual: do not inherit from this class
   ~CHMIGCmessageReceivedResponse(); 

   /** Indicates whether or not the received message was processed.
    * When set to true, this indicates to Iguana that the message was processed successfully. 
    * When set to false, this indicates to Iguana that there was an error while processing the message.
    **/
   void setMessageProcessed(CHMboolean NewValue);
   CHMboolean messageProcessed() const;

   /** Requests that Iguana stop the channel. */
   void setStopChannel(CHMboolean);
   CHMboolean stopChannel() const;

   /** Requests that Iguana stop the channel with the error flag set.
    * Only applicable if StopChannel is also set.
    **/
   void setStopChannelErrorFlag(CHMboolean);
   CHMboolean stopChannelErrorFlag() const;

   /** Describes the reason for the 'stop channel' request.  
    * Only applicable if StopChannel is also set.
    **/
   void setStopChannelReason(const CHMstring&);
   CHMstring stopChannelReason() const;

   /** Requests that Iguana resend the message.  
    * If StopChannel is requested, the message will be resent only after
    * the channel has been stopped and subsequently restarted.  If StopChannel is not requested, the message will
    * be sent after a delay specified by ResendMessageDelay.
    **/
   void setResendMessage( CHMboolean );
   CHMboolean resendMessage() const;

   /** Specifies the minimum time delay, in milliseconds, Iguana should wait before resending the message.
    * Only applicable if ResendMessage is also set (and StopChannel is not set).
    **/
   void setResendMessageDelay( CHMuint32 Milliseconds );
   CHMuint32 resendMessageDelay() const;

   /** Adds a log message to the Iguana logs. */
   void addLogMessage( CHMIGClogMessageType LogMessageType, const CHMstring& LogMessage);

   /** Add a key-value pair to the Iguana logs. */
   void addLogValue(const CHMstring& Key, const CHMstring& Value);

   /** Cancel a key-value pair's addition to the Iguana logs. */
   void removeLogValue(const CHMstring& Key);

   /** Get the log value associated with a log key, or an empty string if not found. */
   CHMstring logValue(const CHMstring& Key);

private:
   CHMIGCdll& Dll;
   void* ResponseHandle;

   CHMIGCmessageReceivedResponse(const CHMIGCmessageReceivedResponse& Orig); // not allowed
   CHMIGCmessageReceivedResponse& operator=(const CHMIGCmessageReceivedResponse& Orig); // not allowed
};

#endif // end of defensive include
