#ifndef __CHM_IGC_MESSAGE_REQUEST_RESPONSE_H__
#define __CHM_IGC_MESSAGE_REQUEST_RESPONSE_H__
//---------------------------------------------------------------------------
// Copyright (C) 1997-2009 iNTERFACEWARE Inc.  All Rights Reserved
//
// Module: CHMIGCmessageRequestResponse
//
// Author: Steven Dodd
// Date:   Jan 20, 2009
// Revision: $Revision: 1.5 $
//
// Last Edit Date: $Date: 2009-02-19 03:35:02 $
// Source: $Source: /home/cvs/cvsroot/CHM/Attic/CHMIGCmessageRequestResponse.h,v $
//---------------------------------------------------------------------------

#include <CHM/CHMminimumInclude.h>
#include <CHM/CHMIGCdll.h>

class CHMstring;

/** Captures plugin response to an CHMIGCsource::onMessageRequest() event. */
class CHMIGCmessageRequestResponse 
{
public:
   //This is used internally, not for external use.
   CHMIGCmessageRequestResponse(CHMIGCdll& Dll, void* ResponseHandle);

   // non-virtual: do not inherit from this class
   ~CHMIGCmessageRequestResponse(); 

   /** Set to either the generated message, or to an empty string if a message is unavailable
    * (Iguana will poll again later).  Ignored if StopChannel is set - it is not possible to
    * transmit a  and request 'stop channel' simultaneously.
	 * Deprecated behavior: if MessageIsError is set, the contents of OutboundMessage are
	 * interpreted as an error-level log message.  This behavior has been retained for backwards
	 * compatibility with existing plugins.  New or updated plugins should use the AddLogMessage
	 * method instead.
    **/
   void setOutboundMessage(const CHMstring& NewValue);
   CHMstring outboundMessage() const;

   /** MessageIsError has been superseded by the more general AddLogMessage method.  This method is 
	 * retained for backwards compatibility with existing plugins.  New or updated plugins should 
	 * use the AddLogMessage method instead.
	 * Indicates that OutboundMessage should be interpreted as an error-level log message.
    **/
   void setMessageIsError(CHMboolean);
   CHMboolean messageIsError() const;

   /** Plugin Message ID value returned in CHMIGCsource::onMessageRequestCompleted().
    * The received Plugin Message ID indicates that the message was processed.
    **/
   void setMessageId(const CHMstring& PluginMessageId);
   CHMstring messageId() const;

   /** Requests that Iguana stop the channel. */
   void setStopChannel(CHMboolean);
   CHMboolean stopChannel() const;

   /** Requests that Iguana stop the channel with the error flag set.
    * Only applicable if StopChannel is also set.
    **/
   void setStopChannelErrorFlag(CHMboolean);
   CHMboolean stopChannelErrorFlag() const;

   /** Describes the reason for the 'stop channel' request.  
    * Only applicable if StopChannel is also set.
    **/
   void setStopChannelReason(const CHMstring&);
   CHMstring stopChannelReason() const;

   /** Adds a log message to the Iguana logs. */
   void addLogMessage( CHMIGClogMessageType LogMessageType, const CHMstring& LogMessage);

   /** Add a key-value pair to the Iguana logs. */
   void addLogValue(const CHMstring& Key, const CHMstring& Value);

   /** Cancel a key-value pair's addition to the Iguana logs. */
   void removeLogValue(const CHMstring& Key);

   /** Get the log value associated with a log key, or an empty string if not found. */
   CHMstring logValue(const CHMstring& Key);

private:
   void* ResponseHandle;
   CHMIGCdll& Dll;

   CHMIGCmessageRequestResponse(const CHMIGCmessageRequestResponse& Orig); // not allowed
   CHMIGCmessageRequestResponse& operator=(const CHMIGCmessageRequestResponse& Orig); // not allowed
};

#endif // end of defensive include
